==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/desktop-utils/lumina-fileinfo/i18n/l-fileinfo_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="24"/>
        <location filename="../MainUI.cpp" line="97"/>
        <source>File Information</source>
        <translation>Filinformation</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="56"/>
        <source>Owner:</source>
        <translation>Ägare:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="73"/>
        <source>Group:</source>
        <translation>Grupp:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Permissions:</source>
        <translation>Behörigheter:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="104"/>
        <source>Created:</source>
        <translation>Skapad:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="111"/>
        <source>Note: The time a file was created might be more recent than the time modified if the file permissions were changed recently.</source>
        <translation>Obs: Tiden en fil skapades kan vara nyare än den tid ändras om filrättigheterna ändrades nyligen.</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Last Modified:</source>
        <translation>Senast ändrad:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="131"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>MimeType:</source>
        <translation>MIME-typ:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="185"/>
        <source>File Size:</source>
        <translation>Filstorlek:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="216"/>
        <location filename="../MainUI.cpp" line="140"/>
        <source>Edit Shortcut</source>
        <translation>Redigera genväg</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>Working Dir:</source>
        <translation>Arbetskatalog:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="246"/>
        <source>Use startup notification</source>
        <translation>Använd uppstartsnotifiering</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="260"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="267"/>
        <source>Command:</source>
        <translation>Kommando:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="274"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="284"/>
        <source>Run in terminal</source>
        <translation>Kör i terminal</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Options</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="336"/>
        <source>No Icon</source>
        <translation>Ingen ikon</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="61"/>
        <source>---Calculating---</source>
        <translation>---Beräknar---</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="70"/>
        <source>Read/Write</source>
        <translation>Läs/Skriv</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="71"/>
        <source>Read Only</source>
        <translation>Skrivskyddad</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="72"/>
        <source>Write Only</source>
        <translation>Endast skriva</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="73"/>
        <source>No Access</source>
        <translation>Ingen åtkomst</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>XDG Shortcut</source>
        <translation>XDG Genväg</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="78"/>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="79"/>
        <source>Binary</source>
        <translation>Binär</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="81"/>
        <source>Hidden %1</source>
        <translation>Dold %1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="126"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Save Application File</source>
        <translation>Spara Program fil</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Application Registrations (*.desktop)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="290"/>
        <source>Select a binary</source>
        <translation>Välj en binär</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="293"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="293"/>
        <source>Invalid selection: Not a valid executable</source>
        <translation>Ogiltig val: Inte giltig körbar fil</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="305"/>
        <source>Select a directory</source>
        <translation>Välj en katalog</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="318"/>
        <source>Select an icon</source>
        <translation>Välj en ikon</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="318"/>
        <source>Images (%1);; All Files (*)</source>
        <translation>Bilder (%1);; Alla Filer (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <location filename="../MainUI.cpp" line="343"/>
        <source> Folders: </source>
        <translation> Mappar:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <location filename="../MainUI.cpp" line="343"/>
        <source>Files: </source>
        <translation>Filer: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="343"/>
        <source>  Calculating...</source>
        <translation> Beräknar...</translation>
    </message>
</context>
</TS>

==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/desktop-utils/lumina-fileinfo/i18n/l-fileinfo_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="24"/>
        <location filename="../MainUI.cpp" line="96"/>
        <source>File Information</source>
        <translation>Filinformation</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="56"/>
        <source>Owner:</source>
        <translation>Ägare:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="73"/>
        <source>Group:</source>
        <translation>Grupp:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Permissions:</source>
        <translation>Behörigheter:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="104"/>
        <source>Created:</source>
        <translation>Skapad:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="111"/>
        <source>Note: The time a file was created might be more recent than the time modified if the file permissions were changed recently.</source>
        <translation>Obs: Tiden en fil skapades kan vara nyare än den tid filen sist ändrades om filrättigheterna ändrades nyligen.</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Last Modified:</source>
        <translation>Senast ändrad:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="131"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>MimeType:</source>
        <translation>MIME-typ:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="185"/>
        <source>File Size:</source>
        <translation>Filstorlek:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="216"/>
        <location filename="../MainUI.cpp" line="139"/>
        <source>Edit Shortcut</source>
        <translation>Redigera genväg</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>Working Dir:</source>
        <translation>Arbetskatalog:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="246"/>
        <source>Use startup notification</source>
        <translation>Använd uppstartsnotifiering</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="260"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="267"/>
        <source>Command:</source>
        <translation>Kommando:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="274"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="284"/>
        <source>Run in terminal</source>
        <translation>Kör i terminal</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Options</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="336"/>
        <source>No Icon</source>
        <translation>Ingen ikon</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="60"/>
        <source>---Calculating---</source>
        <translation>---Beräknar---</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="69"/>
        <source>Read/Write</source>
        <translation>Läs/Skriv</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="70"/>
        <source>Read Only</source>
        <translation>Skrivskyddad</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="71"/>
        <source>Write Only</source>
        <translation>Endast skriva</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="72"/>
        <source>No Access</source>
        <translation>Ingen åtkomst</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="76"/>
        <source>XDG Shortcut</source>
        <translation>XDG Genväg</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="78"/>
        <source>Binary</source>
        <translation>Binär</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="80"/>
        <source>Hidden %1</source>
        <translation>Dold %1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="125"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="247"/>
        <source>Save Application File</source>
        <translation>Spara programfil</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="247"/>
        <source>Application Registrations (*.desktop)</source>
        <translation>Applikationsregistreringar (*.desktop)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="288"/>
        <source>Select a binary</source>
        <translation>Välj en binär</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="291"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="291"/>
        <source>Invalid selection: Not a valid executable</source>
        <translation>Ogiltigt val: Inte giltig körbar fil</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="303"/>
        <source>Select a directory</source>
        <translation>Välj en katalog</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="316"/>
        <source>Select an icon</source>
        <translation>Välj en ikon</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="316"/>
        <source>Images (%1);; All Files (*)</source>
        <translation>Bilder (%1);; Alla filer (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="339"/>
        <location filename="../MainUI.cpp" line="341"/>
        <source> Folders: </source>
        <translation> Mappar: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="339"/>
        <location filename="../MainUI.cpp" line="341"/>
        <source>Files: </source>
        <translation>Filer: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <source>  Calculating...</source>
        <translation>  Beräknar...</translation>
    </message>
</context>
</TS>
